# maegatk 

[![PyPI version](https://badge.fury.io/py/maegatk.svg)](https://pypi.python.org/pypi/mgaeatk)
[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[![Downloads](https://pepy.tech/badge/maegatk/month)](https://pepy.tech/project/maegatk)

Mitochondrial Alteration Enrichment and Genome Analysis Toolkit

### Dependencies

- java in the environment
- bwa in the environment
- bedtools in the environment

### Installation

With python3, simply install via `pip`

```
pip3 install maegatk
```

### Contact
Raise an issue on the repository with any issues getting this toolkit working. 

<br><br>
